#
# spec file for package libpsm2
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
#The tarball is generated using
# git clone https://github.com/01org/opa-psm2
# cd opa-psm2
# git checkout 85c07c656198204c4056e1984779fde98b00ba39
# make dist

%define psm_so 2
Name:           libpsm2
Version:        0.7
Release:        1.12
Summary:        Intel PSM Libraries
License:        BSD-2-Clause or GPL-2.0
Group:          Development/Libraries
Url:            http://www.intel.com/
Source:         %{name}-%{version}.tar.gz
Patch1:         libpsm2-avoid-executable-flag-on-installed-header-files.patch
Patch2:         libpsm2-use_RPM_OPT_FLAGS.patch
Patch3:			libpsm2-use-exported-variable-for-version-and-release.patch
BuildRequires:  libuuid-devel
BuildRequires:  pkg-config
BuildRequires:  udev
Conflicts:      opa-libs
Obsoletes:      hfi-psm
Obsoletes:      hfi-psm-debuginfo
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#Currently *only* builds on x86_64
ExclusiveArch:  x86_64

%description
The PSM Messaging API, or PSM API, is Intel's low-level
user-level communications interface for the Truescale
family of products. PSM users are enabled with mechanisms
necessary to implement higher level communications
interfaces in parallel environments.

%package     -n %{name}-%{psm_so}
Summary:        Runtime PSM library
Group:          System/Libraries
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description -n %{name}-%{psm_so}
libpsm2 provides PSM Messaging API, or PSM API, is Intel's low-level
user-level communications interface for the Truescale
family of products. This package contains the runtime library.

%package        devel
Summary:        Development files for Intel PSM
Group:          Development/Libraries/C and C++
Requires:       %{name}-%{psm_so} = %{version}
Requires:       libuuid-devel
Conflicts:      opa-devel

%package        compat
Summary:        Development files for Intel PSM
Group:          Development/Libraries
Requires:       %{name}-%{psm_so} = %{version}
#Obsoletes:      hfi-psm-compat

%description    devel
Development files for the libpsm2 library

%description    compat
Support for MPIs linked with PSM versions < 2

%prep
%setup -q -n %{name}-%{version}
%patch1 -p1
%patch2
%patch3 -p1

%build
export RPM_OPT_FLAGS
export VERSION=${Version} RELEASE=${Release}
make %{?_smp_mflags}

%install
export DESTDIR=%{buildroot}
make %{?_smp_mflags} DESTDIR=%{buildroot} install
mkdir -p -m 0755 -p %{buildroot}/%{_libdir}/psm2
install -m0644 %{buildroot}/%{_libdir}/psm2-compat/libpsm_infinipath.so.1 %{buildroot}/%{_libdir}/psm2/libpsm_infinipath.so.1
# removing file to get rid of rpm errors
rm  %{buildroot}/%{_libdir}/psm2-compat/libpsm_infinipath.so.1
rm %{buildroot}/%{_sbindir}/hfi1-psm-compat.cmds

%post -n %{name}-%{psm_so} -p /sbin/ldconfig
%postun -n %{name}-%{psm_so} -p /sbin/ldconfig
%post devel -p /sbin/ldconfig
%postun devel -p /sbin/ldconfig

%files -n %{name}-%{psm_so}
%defattr(-,root,root,-)
%{_libdir}/libpsm2.so.*
%{_udevrulesdir}/40-psm.rules
%doc COPYING README

%files devel
%defattr(-,root,root,-)
%{_libdir}/libpsm2.so
%{_includedir}/psm2.h
%{_includedir}/psm2_mq.h
%{_includedir}/psm2_am.h

# The following files were part of the devel-noship and moved to devel:
%dir %{_includedir}/hfi1diag/
%dir %{_includedir}/hfi1diag/linux-x86_64/
%dir %{_includedir}/hfi1diag/ptl_ips/

%{_includedir}/hfi1diag/ptl_ips/ipserror.h
%{_includedir}/hfi1diag/linux-x86_64/bit_ops.h
%{_includedir}/hfi1diag/linux-x86_64/sysdep.h
%{_includedir}/hfi1diag/opa_udebug.h
%{_includedir}/hfi1diag/opa_debug.h
%{_includedir}/hfi1diag/opa_intf.h
%{_includedir}/hfi1diag/opa_user.h
%{_includedir}/hfi1diag/opa_service.h
%{_includedir}/hfi1diag/opa_common.h
%{_includedir}/hfi1diag/opa_byteorder.h

%files compat
%defattr(-,root,root,-)
%dir %{_libdir}/psm2/
%dir %{_sysconfdir}/modprobe.d

%{_libdir}/psm2/libpsm_infinipath.so.*
%{_udevrulesdir}/40-psm-compat.rules
%config %{_sysconfdir}/modprobe.d/hfi1-psm-compat.conf

%changelog
* Thu Jun  9 2016 ndas@suse.de
- Removed git from buildrequires and specify version and revision using
  environment variables (bsc#983235).
  [+libpsm2-use-exported-variable-for-version-and-release.patch]
- Added a _service file(bsc#983235).
* Fri May 27 2016 ndas@suse.de
- Removed hfi1_user.h from the source as the required changes
  are available in kernel-devel's hfi1_user.h(bsc#980733).
  [-hfi1_user.h]
* Wed Mar 23 2016 ndas@suse.de
- Fix build error (bsc#972292).
* Fri Mar 11 2016 pth@suse.de
- Fix dependency of libpsm2-devel and -compat(bsc#970895).
* Wed Mar  9 2016 pth@suse.de
- Add libpsm2-use_RPM_OPT_FLAGS.patch to include RPM_OPT_FLAGS
  in CFLAGS.
- Do not recreate RPM_BUILD_ROOT.
- Remove unneeded %%clean section
* Wed Mar  2 2016 nirmoy.das@suse.com
- Initial Package, Version 0.7(fate#319243).
